# copy_transplant

[![Source code](https://img.shields.io/badge/Source-Github-4051b5)](https://github.com/JasonLo/connectionist/blob/main/connectionist/surgery.py)
::: connectionist.surgery.copy_transplant
